@@ -20,7 +20,7 @@ use Exporter::Easy (
         chapter_3_test)]
 );
 
-# return a dataset containing training data from chapter 3
+# return a dataset containing training items from chapter 3
 sub chapter_3_train {
     my $train = Algorithm::AM::DataSet->new(cardinality => 3);
     for my $datum(chapter_3_data()){
@@ -44,17 +44,7 @@ sub chapter_3_test {
     return $test;
 }
 
-# return a project pre-loaded with chapter 3 data
-sub chapter_3_project {
-    my $project = Algorithm::AM::Project->new(variables => 3);
-    for my $datum(chapter_3_data()){
-        $project->add_data(@$datum);
-    }
-    $project->add_test([qw(3 1 2)], 'r', 'test item comment');
-    return $project;
-}
-
-# return a list of array refs containing the data from chapter 3
+# return a list of array refs containing the items from chapter 3
 sub chapter_3_data {
     return (
         [[qw(3 1 0)], 'e', 'myFirstCommentHere'],
